package jdk.javadoc.internal.tool.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "25-beta+36-ea" },
            { "jdk", "25" },
            { "release", "25-beta" },
        };
    }
}
